@@ -1,17 +1,21 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2020, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
 
 """Example analyses and calculations based on data parsed by cclib."""
 
+from cclib.method.bader import Bader
+from cclib.method.bickelhaupt import Bickelhaupt
 from cclib.method.cda import CDA
 from cclib.method.cspa import CSPA
+from cclib.method.ddec import DDEC6
 from cclib.method.density import Density
 from cclib.method.electrons import Electrons
 from cclib.method.fragments import FragmentAnalysis
+from cclib.method.hirshfeld import Hirshfeld
 from cclib.method.lpa import LPA
 from cclib.method.mbo import MBO
 from cclib.method.moments import Moments
@@ -19,4 +23,5 @@ from cclib.method.mpa import MPA
 from cclib.method.nuclear import Nuclear
 from cclib.method.opa import OPA
 from cclib.method.orbitals import Orbitals
-# from cclib.method.volume import Volume
+from cclib.method.stockholder import Stockholder
+from cclib.method.volume import Volume
