@@ -36,7 +36,7 @@ class ccData:
         coreelectrons -- number of core electrons in atom pseudopotentials (array[1])
         dispersionenergies -- a molecular dispersion energy corrections (array[1], eV)
         enthalpy -- sum of electronic and thermal enthalpies (float, hartree/particle)
-        entropy -- entropy (float, hartree/particle)
+        entropy -- entropy (float, hartree/(particle*kelvin))
         etenergies -- energies of electronic transitions (array[1], 1/cm)
         etoscs -- oscillator strengths of electronic transitions (array[1])
         etdips -- electric transition dipoles of electronic transitions (array[2], ebohr)
@@ -66,6 +66,7 @@ class ccData:
         natom -- number of atoms (integer)
         nbasis -- number of basis functions (integer)
         nmo -- number of molecular orbitals (integer)
+        nmrtensors -- Nuclear magnetic resonance chemical shielding tensors (dict of dicts of array[2])
         nocoeffs -- natural orbital coefficients (array[2])
         nooccnos -- natural orbital occupation numbers (array[1])
         nsocoeffs -- natural spin orbital coefficients (list of array[2])
@@ -76,8 +77,8 @@ class ccData:
         pressure -- pressure used for Thermochemistry (float, atm)
         scancoords -- geometries of each scan step (array[3], angstroms)
         scanenergies -- energies of potential energy surface (list)
-        scannames -- names of varaibles scanned (list of strings)
-        scanparm -- values of parameters in potential energy surface (list of lists)
+        scannames -- names of variables scanned (list of strings)
+        scanparm -- values of parameters in potential energy surface (list of tuples)
         scfenergies -- molecular electronic energies after SCF (Hartree-Fock, DFT) (array[1], eV)
         scftargets -- targets for convergence of the SCF (array[2])
         scfvalues -- current values for convergence of the SCF (list of arrays[2])
@@ -147,6 +148,7 @@ class ccData:
        "natom":            Attribute(int,              'number of atoms',             'properties'),
        "nbasis":           Attribute(int,              'basis number',                'properties:orbitals'),
        "nmo":              Attribute(int,              'MO number',                   'properties:orbitals'),
+       "nmrtensors":       Attribute(dict,             'NMR chemical shielding tensors', 'properties:nmr'),
        "nocoeffs":         Attribute(numpy.ndarray,    'TBD',                         'N/A'),
        "nooccnos":         Attribute(numpy.ndarray,    'TBD',                         'N/A'),
        "nsocoeffs":         Attribute(list,    'TBD',                         'N/A'),
