@@ -116,15 +116,16 @@ class ORCA(logfileparser.Logfile):
             while line[0] != '=':
                 if line.lower()[:7] == 'warning':
                     self.metadata['warnings'].append('')
-                    while len(line) > 1:
+                    while len(line) > 1 and set(line.strip()) != {'='}:
                         self.metadata['warnings'][-1] += line[9:].strip()
                         line = next(inputfile)
                 elif line.lower()[:4] == 'info':
                     self.metadata['info'].append('')
-                    while len(line) > 1:
+                    while len(line) > 1 and set(line.strip()) != {'='}:
                         self.metadata['info'][-1] += line[9:].strip()
                         line = next(inputfile)
-                line = next(inputfile)
+                else:
+                    line = next(inputfile)
 
         # ================================================================================
         #                                        INPUT FILE
@@ -150,7 +151,7 @@ class ORCA(logfileparser.Logfile):
             for line in inputfile:
                 if line[0] != '|':
                     break
-                lines.append(line[6:])
+                lines.append(line[line.find('> ')+2:])
 
             self.metadata['input_file_contents'] = ''.join(lines[:-1])
             lines_iter = iter(lines[:-1])
@@ -170,7 +171,6 @@ class ORCA(logfileparser.Logfile):
                 # Impossible to parse without knowing whether a keyword opens a new block
                 elif line[0] == '%':
                     pass
-
                 # Geometry block
                 elif line[0] == '*':
                     coord_type, charge, multiplicity = line[1:].split()[:3]
@@ -185,7 +185,13 @@ class ORCA(logfileparser.Logfile):
                     elif coord_type in ['int', 'internal']:
                         def splitter(line):
                             atom, a1, a2, a3, bond, angle, dihedral = line.split()[:7]
-                            return [atom, int(a1), int(a2), int(a3), float(bond), float(angle), float(dihedral)]
+                            # This could be some combination of floats and variables
+                            # C                  0    0    0       0.0                  0.0                   0.0
+                            # C                  3    2    1       {B3}                 {A2}                  {D1}
+                            try:
+                                return [atom, int(a1), int(a2), int(a3), float(bond), float(angle), float(dihedral)]
+                            except:
+                                return [atom, int(a1), int(a2), int(a3), str(bond), str(angle), str(dihedral)]
                     elif coord_type == 'gzmt':
                         def splitter(line):
                             vals = line.split()[:7]
@@ -215,10 +221,76 @@ class ORCA(logfileparser.Logfile):
                             # Strip basis specification that can appear after coordinates
                             line = line.split('newGTO')[0].strip()
                             coords.append(splitter(line))
-
             self.metadata['keywords'] = keywords
             self.metadata['coords'] = coords
+        # If the calculations is a unrelaxed parameter scan then immediately following the 
+        # input file block is the following section:
+                
+        # | 12> **                         ****END OF INPUT****
+        # ================================================================================
+        # 
+        #                        ******************************
+        #                        * Parameter Scan Calculation *
+        #                        ******************************
+        # 
+        # Trajectory settings:
+        #     -> SCF surface will be mapped
+        # 
+        # There are 1 parameter(s) to be scanned
+        #              R: range=   0.58220000 ..   5.08220000  steps=   46
+        # There will be   46 energy evaluations
+        #
+        #
+        # following this each calculation has the following block at the start
+        #
+        #         *************************************************************
+        #                                TRAJECTORY STEP   1
+        #                  R  :   0.58220000
+        #         *************************************************************
 
+        if 'Parameter Scan Calculation' in line:
+            self.skip_lines(inputfile,['s', 'b', 'Trajectory settings', 'Surface information', 'b'])
+            line = next(inputfile)
+            num_params = int(line.strip().split()[2])
+            for i in range(num_params):
+                line = next(inputfile).strip()
+                self.append_attribute('scannames', line.split(':')[0])
+        if 'TRAJECTORY STEP' in line:
+            current_params = []
+            for i in range(len(self.scannames)):
+                line = next(inputfile)
+                current_params.append(float(line.split(':')[-1].strip()))
+            self.append_attribute('scanparm', tuple(current_params))
+
+        # If the calculations is a relaxed parameter scan then immediately following the 
+        # input file block is the following section:
+
+        #                        ******************************
+        #                        *    Relaxed Surface Scan    *
+        #                        ******************************
+        # 
+        #         Dihedral (  9,   8,   3,   2):   range=   0.00000000 .. 360.00000000  steps =   12
+        # 
+        # There is 1 parameter to be scanned.
+        # There will be   12 constrained geometry optimizations.
+        # 
+        # 
+        #          *************************************************************
+        #          *               RELAXED SURFACE SCAN STEP   1               *
+        #          *                                                           *
+        #          *   Dihedral (  9,   8,   3,   2)  :   0.00000000           *
+        #          *************************************************************
+
+        if 'Relaxed Surface Scan' in line:
+            self.skip_lines(inputfile,['s', 'b'])
+            line = next(inputfile)
+            while not line.isspace():
+                line = line.strip()
+                self.append_attribute('scannames', line.split(':')[0])
+                line = next(inputfile)
+            line = next(inputfile)
+            num_params = int(line.strip().split()[2])
+        
         if line[0:15] == "Number of atoms":
 
             natom = int(line.split()[-1])
@@ -426,16 +498,17 @@ Dispersion correction           -0.016199959
         # RMS Gradient             TolRMSG  ....  1.0000e-04 Eh/bohr
         # Max. Displacement        TolMAXD  ....  4.0000e-03 bohr
         # RMS Displacement         TolRMSD  ....  2.0000e-03 bohr
-        if line[25:50] == "RELAXED SURFACE SCAN STEP":
+        if 'RELAXED SURFACE SCAN STEP' in line:
+            self.skip_lines(inputfile,['b'])
+            current_params = []
+            for i in range(len(self.scannames)):
+                line = next(inputfile)
+                line = line.replace('*','')
+                current_params.append(float(line.split(':')[-1].strip()))
+            self.append_attribute('scanparm', tuple(current_params))
 
             self.is_relaxed_scan = True
-            blank = next(inputfile)
-            info = next(inputfile)
-            stars = next(inputfile)
-            blank = next(inputfile)
-
-            line = next(inputfile)
-            while line[0:23] != "Convergence Tolerances:":
+            while "Convergence Tolerances:" not in line:
                 line = next(inputfile)
 
             self.geotargets = []
@@ -916,7 +989,7 @@ Dispersion correction           -0.016199959
             while line[:17] != 'Electronic energy':
                 line = next(inputfile)
             self.electronic_energy = float(line.split()[3])
-            self.zpe = float(next(inputfile).split()[4])
+            self.set_attribute("zpve", float(next(inputfile).split()[4]))
             thermal_vibrational_correction = float(next(inputfile).split()[4])
             thermal_rotional_correction = float(next(inputfile).split()[4])
             thermal_translational_correction = float(next(inputfile).split()[4])
@@ -947,7 +1020,7 @@ Dispersion correction           -0.016199959
 
             # ORCA prints -inf for single atom entropy.
             if self.natom > 1:
-                self.entropy = float(next(inputfile).split()[4])
+                self.entropy = float(next(inputfile).split()[4]) / self.temperature
             else:
                 self.entropy = (electronic_entropy + translational_entropy) / self.temperature
 
@@ -1183,18 +1256,31 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
             #         (cm-1)   (nm)       (1e40*cgs)   (au)      (au)      (au)  
             # -------------------------------------------------------------------
             #    1   43167.6    231.7      0.00000   0.00000  -0.00000   0.00000
+            # ...
+            #    6   25291.1    395.4 spin forbidden
             #
+            # OR (from 4.2.0 onwards)
+            #------------------------------------------------------------------------------
+            #                             CD SPECTRUM
+            #------------------------------------------------------------------------------
+            #      States        Energy   Wavelength   R*T        RX        RY        RZ
+            #                    (cm-1)      (nm)   (1e40*sgs)   (au)      (au)      (au)
+            #------------------------------------------------------------------------------
+            #  0( 1)-> 1( 1) 1   37192.8    268.9     0.00000  -0.00000  -0.34085   0.00000
+            # ...
+            #------------------------------------------------------------------------------
             etenergies = []
             etrotats = []
             self.skip_lines(inputfile, ["d", "State   Energy Wavelength", "(cm-1)   (nm)", "d"])
             line = next(inputfile)
-            while line.strip():
+            while line.strip() and not utils.str_contains_only(line.strip(), ['-']):
                 tokens = line.split()
                 if "spin forbidden" in line:
                     etrotat, mx, my, mz = 0.0, 0.0, 0.0, 0.0
+                    etenergies.append(utils.float(tokens[-4]))
                 else:
-                    etrotat, mx, my, mz = [utils.float(t) for t in tokens[3:]]
-                etenergies.append(utils.float(tokens[1]))
+                    etrotat, mx, my, mz = [utils.float(t) for t in tokens[-4:]]
+                    etenergies.append(utils.float(tokens[-6]))
                 etrotats.append(etrotat)
                 line = next(inputfile)
             self.set_attribute("etrotats", etrotats)
@@ -1203,7 +1289,82 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
                                     "the output file may be malformed")
                 self.set_attribute("etenergies", etenergies)
 
+        # ---------------
+        # CHEMICAL SHIFTS
+        # ---------------
+        #
+        # Note: using conversion factor for au to ppm alpha^2/2 =   26.625677252
+        # GIAO: Doing para- and diamagnetic shielding integrals analytically     ...done
+        #  --------------
+        #  Nucleus   0C :
+        #  --------------
+        #
+        # Diamagnetic contribution to the shielding tensor (ppm) :
+        #            261.007         -0.294        -0.000
+        #             -0.093        266.836         0.000
+        #             -0.000         -0.000       244.502
+        #
+        # Paramagnetic contribution to the shielding tensor (ppm):
+        #           -179.969          6.352        -0.000
+        #              3.571       -210.368        -0.000
+        #              0.000          0.000       -31.944
+        #
+        # Total shielding tensor (ppm):
+        #             81.038          6.058        -0.000
+        #              3.478         56.468        -0.000
+        #              0.000          0.000       212.558
+        #
+        #
+        #  Diagonalized sT*s matrix:
+        #
+        #  sDSO           266.692          261.151          244.502  iso=     257.448
+        #  sPSO          -211.114         -179.223          -31.944  iso=    -140.760
+        #         ---------------  ---------------  ---------------
+        #  Total           55.577           81.929          212.558  iso=     116.688
+        # ...
+        #
+        #--------------------------
+        #CHEMICAL SHIELDING SUMMARY (ppm)
+        #--------------------------
+        #
+        #
+        #  Nucleus  Element    Isotropic     Anisotropy
+        #  -------  -------  ------------   ------------
+        #      0       C          116.686        143.809
+        #      1       C          122.158        130.692
+        # ...
+        if line[:15] == 'CHEMICAL SHIFTS':
+            nmrtensors = dict()
+            while line.strip() != 'CHEMICAL SHIELDING SUMMARY (ppm)':
+                if line[:8] == ' Nucleus':
+                    atom = int(re.search(r'Nucleus\s+(\d+)\w', line).groups()[0])
+                    self.skip_lines(inputfile, ['-', ''])
+                    atomtensors = dict()
+                    for _ in range(3):
+                        t_type = next(inputfile).split()[0].lower()
+                        tensor = numpy.zeros((3, 3))
+                        for j, row in zip(range(3), inputfile):
+                            tensor[j, :] = list(map(float, row.split()))
+                        atomtensors[t_type] = tensor
+                        self.skip_line(inputfile, '')
+                    nmrtensors[atom] = atomtensors
+                line = next(inputfile)
+
+            self.skip_lines(inputfile, ['-', '', '', 'text', '-'])
+
+            # Not currently used.
+            isotropic, anisotropic = [], []
+            for line in inputfile:
+                if not line.strip():
+                    break
+                nucleus, element, iso, aniso = line.split()
+                isotropic.append(float(iso))
+                anisotropic.append(float(aniso))
+
+            self.set_attribute('nmrtensors', nmrtensors)
+
         if line[:23] == "VIBRATIONAL FREQUENCIES":
+
             self.skip_lines(inputfile, ['d', 'b'])
 
             # Starting with 4.1, a scaling factor for frequencies is printed
@@ -1453,15 +1614,16 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
             total_el = int(next(inputfile).split()[-1])
             total_orbs = int(next(inputfile).split()[-1])
 
+            line = utils.skip_until_no_match(inputfile, r'^\s*$|^Total number aux.*$|^Determined.*$')
+
             # Determined orbital ranges:
             #    Internal       0 -   -1 (   0 orbitals)
             #    Active         0 -    3 (   4 orbitals)
             #    External       4 -   19 (  16 orbitals)
-            self.skip_lines(inputfile, ['b', 'Determined'])
             orbital_ranges = []
             # Parse the orbital ranges for: Internal, Active, and External orbitals.
             for i in range(3):
-                vals = next(inputfile).split()
+                vals = line.split()
                 start, end, num = int(vals[1]), int(vals[3]), int(vals[5])
                 # Change from inclusive to exclusive in order to match python.
                 end = end + 1
@@ -1485,7 +1647,8 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
             self.skip_line(inputfile, 'CI strategy')
             num_blocks = int(next(inputfile).split()[-1])
             for b in range(1, num_blocks + 1):
-                vals = next(inputfile).split()
+                line = utils.skip_until_no_match(inputfile, r'^\s*$')
+                vals = line.split()
                 block = int(vals[1])
                 weight = float(vals[3])
                 assert b == block
@@ -1551,9 +1714,10 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
             # ROOT   0:  E=     -14.5950507665 Eh
             #       0.89724 [     0]: 2000
             for b in range(num_blocks):
+                line = utils.skip_until_no_match(inputfile, r'^\s*$|^-*$')
                 # Parse the block data.
                 reg = r'BLOCK\s+(\d+) MULT=\s*(\d+) (IRREP=\s*\w+ )?(NROOTS=\s*(\d+))?'
-                groups = re.search(reg, next(inputfile)).groups()
+                groups = re.search(reg, line).groups()
                 block = int(groups[0])
                 mult = int(groups[1])
                 # The irrep will only be printed if using symmetry.
@@ -1602,8 +1766,9 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
                 next(inputfile)
                 for j, line in zip(range(num_orbs), inputfile):
                     density[j][i:i + 6] = list(map(float, line.split()[1:]))
-            self.skip_lines(inputfile, ['Trace', 'b', 'd'])
 
+            line = utils.skip_until_no_match(inputfile, r'^\s*$|^-*$|^Trace.*$|^Extracting.*$')
+            
             # This is only printed for open-shells.
             # -------------------
             # SPIN-DENSITY MATRIX
@@ -1612,7 +1777,7 @@ States  Energy Wavelength    D2        m2        Q2         D2+m2+Q2       D2/TO
             #                   0          1          2          3          4          5
             #       0      -0.003709   0.001410   0.000074  -0.000564  -0.007978   0.000735
             #       1       0.001410  -0.001750  -0.000544  -0.003815   0.008462  -0.004529
-            if next(inputfile).strip() == 'SPIN-DENSITY MATRIX':
+            if line.strip() == 'SPIN-DENSITY MATRIX':
                 self.skip_lines(inputfile, ['d', 'b'])
                 spin_density = numpy.zeros((num_orbs, num_orbs))
                 for i in range(0, num_orbs, 6):
