@@ -10,7 +10,7 @@
 import itertools
 import math
 import re
-
+import datetime
 import numpy
 
 from cclib.parser import logfileparser
@@ -69,7 +69,7 @@ class QChem(logfileparser.Logfile):
         # D(   35) --> V(    3) amplitude =  0.0644
         # S(  1) --> V(  1) amplitude = -0.1628 alpha
         # D(189) --> S(  1) amplitude = -0.0120 beta
-        self.re_tddft = re.compile(r'[SD]\( *(\d+)\) --> [VS]\( *(\d+)\) amplitude = *([^ ]*)( (alpha|beta))?')
+        self.re_tddft = re.compile(r'([SD])\( *(\d+)\) --> ([VS])\( *(\d+)\) amplitude = *([^ ]*)( (alpha|beta))?')
 
         # A maximum of 6 columns per block when printing matrices. The
         # Fock matrix is 4.
@@ -1057,7 +1057,7 @@ cannot be determined. Rerun without `$molecule read`."""
                         while line.strip() != '':
                             re_match = self.re_tddft.search(line)
                             if self.unrestricted:
-                                spin = spinmap[re_match.group(5)]
+                                spin = spinmap[re_match.group(7)]
                             else:
                                 spin = 0
 
@@ -1072,9 +1072,52 @@ cannot be determined. Rerun without `$molecule read`."""
                             else:
                                 assert line[5] == ":"
                                 ttype = line[4]
-                            startidx = int(re_match.group(1)) - 1
-                            endidx = int(re_match.group(2)) - 1 + self.nalpha
-                            contrib = float(re_match.group(3))
+
+                            # get start and end indices of contribution
+                            # as the numbers written in parentheses:
+                            index_pattern = re.compile(r"\(( *\d+)\)")
+                            indices=index_pattern.findall(line)
+                            #assert len(indices)==2 # there must always be a 'start' and 'end' index.
+
+                            if self.unrestricted:
+                                # Here are three different countings: 
+                                # The 'D'oubly occupied orbitals,
+                                # the 'S'ingly occupied (i.e. index > self.nbeta) and
+                                # the 'V'irtual orbitals (index > self.nalpha)
+                                # from or to which the excitation can go:
+
+                                # this is supposed to be the standard case:
+                                n_minor=self.nbeta
+                                n_major=self.nalpha
+                                # but this also can appear 
+                                if self.nbeta > self.nalpha:
+                                   n_minor=self.nalpha
+                                   n_major=self.nbeta
+
+                                # split 'line' by '(' to get three strings due to double occurence of '('.
+                                # From the first and second string (i.e. before the parentheses), take the last character.
+                                if re_match.group(1) == "D":
+                                    startidx = int(indices[0]) - 1
+                                elif re_match.group(1) == "S":
+                                    startidx = int(indices[0]) - 1 + n_minor
+                                    assert startidx < n_major
+                                else:
+                                    startidx=-15
+                                    assert "invalid from_occ"
+
+                                if re_match.group(3) == "S":
+                                    endidx = int(indices[1]) - 1 + n_minor
+                                    assert endidx < n_major
+                                elif re_match.group(3) == "V":
+                                    endidx = int(indices[1]) - 1 + n_major
+                                else:
+                                    assert "invalid to_occ"
+
+                            else:
+                                startidx = int(re_match.group(2)) - 1
+                                endidx = int(re_match.group(4)) - 1 + self.nalpha
+
+                            contrib = float(re_match.group(5))
 
                             start = (startidx, spin)
                             end = (endidx, spin)
@@ -1427,13 +1470,21 @@ cannot be determined. Rerun without `$molecule read`."""
             # For IR-related jobs, the Hessian is printed (dim: 3*natom, 3*natom).
             # Note that this is *not* the mass-weighted Hessian.
             if any(header in line for header in self.hessian_headers):
-                if not hasattr(self, 'hessian'):
-                    dim = 3*self.natom
-                    self.hessian = QChem.parse_matrix(inputfile, dim, dim, self.ncolsblock)
+                dim = 3*self.natom
+                self.set_attribute(
+                    "hessian", QChem.parse_matrix(inputfile, dim, dim, self.ncolsblock)
+                )
 
             # Start of the IR/Raman frequency section.
             if 'VIBRATIONAL ANALYSIS' in line:
 
+                vibfreqs = []
+                vibfconsts = []
+                vibrmasses = []
+                vibirs = []
+                vibramans = []
+                vibdisps = []
+
                 while 'STANDARD THERMODYNAMIC QUANTITIES' not in line:
                     ## IR, optional Raman:
                     #
@@ -1475,39 +1526,22 @@ cannot be determined. Rerun without `$molecule read`."""
                     # if not hasattr(self, 'vibsyms'):
                     #     self.vibsyms = []
                     if 'Frequency:' in line:
-                        if not hasattr(self, 'vibfreqs'):
-                            self.vibfreqs = []
-                        vibfreqs = map(float, line.split()[1:])
-                        self.vibfreqs.extend(vibfreqs)
+                        vibfreqs.extend(map(float, line.split()[1:]))
 
                     if 'Force Cnst:' in line:
-                        if not hasattr(self, 'vibfconsts'):
-                            self.vibfconsts = []
-                        vibfconsts = map(float, line.split()[2:])
-                        self.vibfconsts.extend(vibfconsts)
+                        vibfconsts.extend(map(float, line.split()[2:]))
 
                     if 'Red. Mass' in line:
-                        if not hasattr(self, 'vibrmasses'):
-                            self.vibrmasses = []
-                        vibrmasses = map(float, line.split()[2:])
-                        self.vibrmasses.extend(vibrmasses)
+                        vibrmasses.extend(map(float, line.split()[2:]))
 
                     if 'IR Intens:' in line:
-                        if not hasattr(self, 'vibirs'):
-                            self.vibirs = []
-                        vibirs = map(float, line.split()[2:])
-                        self.vibirs.extend(vibirs)
+                        vibirs.extend(map(float, line.split()[2:]))
 
                     if 'Raman Intens:' in line:
-                        if not hasattr(self, 'vibramans'):
-                            self.vibramans = []
-                        vibramans = map(float, line.split()[2:])
-                        self.vibramans.extend(vibramans)
+                        vibramans.extend(map(float, line.split()[2:]))
 
                     # This is the start of the displacement block.
                     if line.split()[0:3] == ['X', 'Y', 'Z']:
-                        if not hasattr(self, 'vibdisps'):
-                            self.vibdisps = []
                         disps = []
                         for k in range(self.natom):
                             line = next(inputfile)
@@ -1518,7 +1552,7 @@ cannot be determined. Rerun without `$molecule read`."""
                                     disps.append([])
                             for n in range(N):
                                 disps[n].append(numbers[3*n:(3*n)+3])
-                        self.vibdisps.extend(disps)
+                        vibdisps.extend(disps)
 
                     line = next(inputfile)
 
@@ -1535,6 +1569,19 @@ cannot be determined. Rerun without `$molecule read`."""
                     #             self.vibanharms.append(float(line.split()[-1]))
                     #         line = next(inputfile)
 
+                if vibfreqs:
+                    self.set_attribute("vibfreqs", vibfreqs)
+                if vibfconsts:
+                    self.set_attribute("vibfconsts", vibfconsts)
+                if vibrmasses:
+                    self.set_attribute("vibrmasses", vibrmasses)
+                if vibirs:
+                    self.set_attribute("vibirs", vibirs)
+                if vibramans:
+                    self.set_attribute("vibramans", vibramans)
+                if vibdisps:
+                    self.set_attribute("vibdisps", vibdisps)
+
             if 'STANDARD THERMODYNAMIC QUANTITIES AT' in line:
 
                 if not hasattr(self, 'temperature'):
@@ -1554,8 +1601,8 @@ cannot be determined. Rerun without `$molecule read`."""
                     assert 'Zero point vibrational energy' in line
                     if not hasattr(self, 'zpe'):
                         # Convert from kcal/mol to Hartree/particle.
-                        self.zpe = utils.convertor(float(line.split()[4]),
-                                                   'kcal/mol', 'hartree')
+                        self.zpve = utils.convertor(float(line.split()[4]),
+                                                    'kcal/mol', 'hartree')
                     atommasses = []
                     while 'Translational Enthalpy' not in line:
                         if 'Has Mass' in line:
@@ -1577,20 +1624,37 @@ cannot be determined. Rerun without `$molecule read`."""
                 line = next(inputfile)
                 assert 'Total Entropy' in line
                 if not hasattr(self, 'entropy'):
-                    entropy = float(line.split()[2]) * self.temperature / 1000
+                    entropy = float(line.split()[2]) / 1000
                     # This is the *temperature dependent* entropy.
                     self.entropy = utils.convertor(entropy,
                                                    'kcal/mol', 'hartree')
                 if not hasattr(self, 'freeenergy'):
-                    self.freeenergy = self.enthalpy - self.entropy
+                    self.freeenergy = self.enthalpy - self.entropy * self.temperature
 
+        # Extract total elapsed (wall) and CPU job times
         if line[:16] == ' Total job time:':
             self.metadata['success'] = True
+            # create empty list for the times to be stored in
+            if not "wall_time" in self.metadata:
+                self.metadata['wall_time'] = []
+            if not "cpu_time" in self.metadata:
+                self.metadata['cpu_time'] = []
+            # the line format is " Total job time:  120.37s(wall), 2251.02s(cpu)" at the end of each job ran. 
+            # first split the line by white space
+            try:
+                a = line.split()
+                # next split the second to last entry at the 's' to pull wall time
+                # cast as a float for use in timedelta data structure
+                wall_td = datetime.timedelta(seconds=float(a[-2].split('s')[0]))
+                # next split the last entry at the 's' to pull cpu time
+                # cast as a float for use in timedelta data structure
+                cpu_td = datetime.timedelta(seconds=float(a[-1].split('s')[0]))
+                self.metadata['wall_time'].append(wall_td)
+                self.metadata['cpu_time'].append(cpu_td)
+            except:
+                pass
 
         # TODO:
-        # 'enthalpy' (incorrect)
-        # 'entropy' (incorrect)
-        # 'freeenergy' (incorrect)
         # 'nocoeffs'
         # 'nooccnos'
         # 'vibanharms'
